@@ -1,8 +1,9 @@
 from __future__ import annotations
 
-import typing
 import warnings
+from collections.abc import Callable, Mapping, Sequence
 from os import PathLike
+from typing import Any, cast, overload
 
 from starlette.background import BackgroundTask
 from starlette.datastructures import URL
@@ -28,10 +29,10 @@ except ModuleNotFoundError:  # pragma: no cover
 class _TemplateResponse(HTMLResponse):
     def __init__(
         self,
-        template: typing.Any,
-        context: dict[str, typing.Any],
+        template: Any,
+        context: dict[str, Any],
         status_code: int = 200,
-        headers: typing.Mapping[str, str] | None = None,
+        headers: Mapping[str, str] | None = None,
         media_type: str | None = None,
         background: BackgroundTask | None = None,
     ):
@@ -43,7 +44,7 @@ class _TemplateResponse(HTMLResponse):
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         request = self.context.get("request", {})
         extensions = request.get("extensions", {})
-        if "http.response.debug" in extensions:
+        if "http.response.debug" in extensions:  # pragma: no branch
             await send(
                 {
                     "type": "http.response.debug",
@@ -63,30 +64,30 @@ class Jinja2Templates:
     return templates.TemplateResponse("index.html", {"request": request})
     """
 
-    @typing.overload
+    @overload
     def __init__(
         self,
-        directory: str | PathLike[str] | typing.Sequence[str | PathLike[str]],
+        directory: str | PathLike[str] | Sequence[str | PathLike[str]],
         *,
-        context_processors: list[typing.Callable[[Request], dict[str, typing.Any]]] | None = None,
-        **env_options: typing.Any,
+        context_processors: list[Callable[[Request], dict[str, Any]]] | None = None,
+        **env_options: Any,
     ) -> None: ...
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         *,
         env: jinja2.Environment,
-        context_processors: list[typing.Callable[[Request], dict[str, typing.Any]]] | None = None,
+        context_processors: list[Callable[[Request], dict[str, Any]]] | None = None,
     ) -> None: ...
 
     def __init__(
         self,
-        directory: str | PathLike[str] | typing.Sequence[str | PathLike[str]] | None = None,
+        directory: str | PathLike[str] | Sequence[str | PathLike[str]] | None = None,
         *,
-        context_processors: list[typing.Callable[[Request], dict[str, typing.Any]]] | None = None,
+        context_processors: list[Callable[[Request], dict[str, Any]]] | None = None,
         env: jinja2.Environment | None = None,
-        **env_options: typing.Any,
+        **env_options: Any,
     ) -> None:
         if env_options:
             warnings.warn(
@@ -105,8 +106,8 @@ class Jinja2Templates:
 
     def _create_env(
         self,
-        directory: str | PathLike[str] | typing.Sequence[str | PathLike[str]],
-        **env_options: typing.Any,
+        directory: str | PathLike[str] | Sequence[str | PathLike[str]],
+        **env_options: Any,
     ) -> jinja2.Environment:
         loader = jinja2.FileSystemLoader(directory)
         env_options.setdefault("loader", loader)
@@ -117,10 +118,10 @@ class Jinja2Templates:
     def _setup_env_defaults(self, env: jinja2.Environment) -> None:
         @pass_context
         def url_for(
-            context: dict[str, typing.Any],
+            context: dict[str, Any],
             name: str,
             /,
-            **path_params: typing.Any,
+            **path_params: Any,
         ) -> URL:
             request: Request = context["request"]
             return request.url_for(name, **path_params)
@@ -130,32 +131,32 @@ class Jinja2Templates:
     def get_template(self, name: str) -> jinja2.Template:
         return self.env.get_template(name)
 
-    @typing.overload
+    @overload
     def TemplateResponse(
         self,
         request: Request,
         name: str,
-        context: dict[str, typing.Any] | None = None,
+        context: dict[str, Any] | None = None,
         status_code: int = 200,
-        headers: typing.Mapping[str, str] | None = None,
+        headers: Mapping[str, str] | None = None,
         media_type: str | None = None,
         background: BackgroundTask | None = None,
     ) -> _TemplateResponse: ...
 
-    @typing.overload
+    @overload
     def TemplateResponse(
         self,
         name: str,
-        context: dict[str, typing.Any] | None = None,
+        context: dict[str, Any] | None = None,
         status_code: int = 200,
-        headers: typing.Mapping[str, str] | None = None,
+        headers: Mapping[str, str] | None = None,
         media_type: str | None = None,
         background: BackgroundTask | None = None,
     ) -> _TemplateResponse:
         # Deprecated usage
         ...
 
-    def TemplateResponse(self, *args: typing.Any, **kwargs: typing.Any) -> _TemplateResponse:
+    def TemplateResponse(self, *args: Any, **kwargs: Any) -> _TemplateResponse:
         if args:
             if isinstance(args[0], str):  # the first argument is template name (old style)
                 warnings.warn(
@@ -168,9 +169,9 @@ class Jinja2Templates:
                 name = args[0]
                 context = args[1] if len(args) > 1 else kwargs.get("context", {})
                 status_code = args[2] if len(args) > 2 else kwargs.get("status_code", 200)
-                headers = args[2] if len(args) > 2 else kwargs.get("headers")
-                media_type = args[3] if len(args) > 3 else kwargs.get("media_type")
-                background = args[4] if len(args) > 4 else kwargs.get("background")
+                headers = args[3] if len(args) > 3 else kwargs.get("headers")
+                media_type = args[4] if len(args) > 4 else kwargs.get("media_type")
+                background = args[5] if len(args) > 5 else kwargs.get("background")
 
                 if "request" not in context:
                     raise ValueError('context must include a "request" key')
@@ -195,7 +196,7 @@ class Jinja2Templates:
 
             context = kwargs.get("context", {})
             request = kwargs.get("request", context.get("request"))
-            name = typing.cast(str, kwargs["name"])
+            name = cast(str, kwargs["name"])
             status_code = kwargs.get("status_code", 200)
             headers = kwargs.get("headers")
             media_type = kwargs.get("media_type")
